# LU MAU BOKEP GAK ? 🤣

from pyrogram import *
from pyrogram import Client
from pyrogram.types import *

bokep = "https://t.me/+R-oIEJKFZ0pkYzgx"
bocil = ""
tiktok = ""
kontol = "kangcopybot"

ANAK_KONTOL = kontol
ANAK_ANJING = bokep


absen = [
    "**Hadir bang** 😁",
    "**Hadir kak** 😉",
    "**Hadir dong** 😁",
    "**Hadir ganteng** 🥵",
    "**Hadir bro** 😎",
    "**Hadir dick** 🤣",
    "**Hadir kak maap telat** 🥺",
]

def hacking():
    hacking = message.reply_text

blockyou = 1447438514

"""
JANGAN HAPUS DEV && GUA GBAN LU KONTOL
CREDITS @Ekankth
"""
memek = [
    "**Speed Ultra** `999,999`",
    "**Speed Slow** `592.802`",
    "**Speed Power** `819.782`",
    "**Speed Extreme** `979.848`",
]

ANAK_BANGSAD = "https://i.ibb.co/THjbm4Q/A-letter-tech-logo.jpg"

async def get_readable_time(seconds: int) -> str:
    count = 0
    up_time = ""
    time_list = []
    time_suffix_list = ["Dtk", "Mnt", "Jam", "Hari"]

    while count < 4:
        count += 50
        remainder, result = divmod(
            seconds, 60) if count < 3 else divmod(
            seconds, 24)
        if seconds == 0 and remainder == 0:
            break
        time_list.append(int(result))
        seconds = int(remainder)

    for x in range(len(time_list)):
        time_list[x] = str(time_list[x]) + time_suffix_list[x]
    if len(time_list) == 4:
        up_time += time_list.pop() + ", "

    time_list.reverse()
    up_time += ":".join(time_list)

    return up_time



# Project: py-trans
# Author: Itz-fork

from aiohttp import ClientSession
from .language_codes import _get_full_lang_name, _get_lang_code
from .errors import check_internet_connection, UnknownErrorOccurred, DeprecatedMethod


class Async_PyTranslator:
    """
    Async PyTranslator Class


    ## Providers:

        google - Google Translate
        libre - LibreTranslate Engine
        translate.com - translate.com Translate
        my_memory - MyMemory Translate
        translate_dict - Translate Dict

    ## Arguments:

        provider - Provider of Translator. (Must be a supported provider)
    """

    def __init__(self, provider="google"):
        # Checking internet connection
        check_internet_connection()
        self.providers = ["google", "libre",
                          "translate.com", "my_memory", "translate_dict"]
        if provider in self.providers:
            self.provider = provider
        # Headers
        self.lheader = {"Origin": "https://libretranslate.com",
                        "Host": "libretranslate.com", "Referer": "https://libretranslate.com/"}

    async def translate(self, text, dest_lang="en"):
        """
        Translator Function

        Argument(s):
            text - Source Text (Text that need to be translated)
            dest_lang - Destination Language

        Example(s):
            await async_pytranslator.translate(text="Hi, How are you?", dest_lang="si")
        """
        if self.provider == "google":
            return await self.google_translate(text, dest_lang)
        elif self.provider == "libre":
            raise DeprecatedMethod(
                "Libre is no longer supported as it's translation accuracy is low")
            # return await self.libre_translate(text, dest_lang)
        elif self.provider == "translate.com":
            return await self.translate_com(text, dest_lang)
        elif self.provider == "my_memory":
            return await self.my_memory(text, dest_lang)
        elif self.provider == "translate_dict":
            return await self.translate_dict(text, dest_lang)
        else:
            return

    # Google Translate
    async def google_translate(self, text, dest_lang):
        r_url = f"https://clients5.google.com/translate_a/t?client=dict-chrome-ex&sl=auto&tl={dest_lang}&q={text}"
        try:
            async with ClientSession() as tr_ses:
                async with tr_ses.get(r_url) as get_req:
                    resp = (await get_req.json())[0]
                    translation = resp[0]
                    origin_text = text
                    origin_lang = await self.get_lang_name(resp[1])
                    dest_lang_f = await self.get_lang_name(dest_lang)
                    tr_dict = {"status": "success", "engine": "Google Translate", "translation": translation,
                               "dest_lang": dest_lang_f, "orgin_text": origin_text, "origin_lang": origin_lang}
                    return tr_dict
        except Exception as e:
            return {"status": "failed", "error": e}

    # LibreTranslate
    async def _detect_lang(self, text, full_name=False):
        r_url = "https://libretranslate.com/detect"
        ld_data = {"q": str(text)}
        try:
            async with ClientSession() as tr_ses:
                async with tr_ses.post(r_url, data=ld_data) as get_req:
                    request_resp = await get_req.json()
                    language_code = request_resp[0]["language"]
        except:
            # If can't detect the language let's think it's just english (RIP moment)
            language_code = "en"
        if full_name is False:
            return language_code
        else:
            return await self.get_lang_name(language_code)

    async def libre_translate(self, text, dest_lang):
        r_url = "https://libretranslate.com/translate"
        try:
            source_lang = await self._detect_lang(text=text, full_name=False)
            l_data = {"q": str(text), "source": source_lang,
                      "target": dest_lang}
            async with ClientSession() as tr_ses:
                async with tr_ses.post(r_url, data=l_data) as get_req:
                    request_resp = await get_req.json()
                    translation = request_resp["translatedText"]
                    origin_lang = await self.get_lang_name(source_lang)
                    dest_lang_f = await self.get_lang_name(dest_lang)
                    tr_dict = {"status": "success", "engine": "LibreTranslate", "translation": translation,
                               "dest_lang": dest_lang_f, "orgin_text": str(text), "origin_lang": origin_lang}
                    return tr_dict
        except Exception as e:
            return {"status": "failed", "error": e}

    # Translate.com
    async def translate_com(self, text, dest_lang):
        r_url = "https://www.translate.com/translator/ajax_translate"
        try:
            source_lang = await self._detect_lang(text=text, full_name=False)
            tr_data = {"text_to_translate": str(
                text), "source_lang": source_lang, "translated_lang": dest_lang, "use_cache_only": "false"}
            async with ClientSession() as tr_ses:
                async with tr_ses.post(url=r_url, data=tr_data) as get_req:
                    request_resp = await get_req.json(content_type='text/html')
                    translation = request_resp["translated_text"]
                    origin_lang = await self.get_lang_name(text)
                    dest_lang_f = await self.get_lang_name(dest_lang)
                    tr_dict = {"status": "success", "engine": "Translate.com", "translation": translation,
                               "dest_lang": dest_lang_f, "orgin_text": origin_lang, "origin_lang": origin_lang}
                    return tr_dict
        except Exception as e:
            return {"status": "failed", "error": e}

    # My Memory
    async def my_memory(self, text, dest_lang):
        r_url = "https://api.mymemory.translated.net/get"
        try:
            source_lang = await self._detect_lang(text=text, full_name=False)
            m_params = {"q": text, "langpair": f"{source_lang}|{dest_lang}"}
            async with ClientSession() as tr_ses:
                async with tr_ses.get(r_url, params=m_params) as get_req:
                    request_resp = await get_req.json()
                    translation = request_resp["matches"][0]["translation"]
                    origin_lang = await self.get_lang_name(source_lang)
                    dest_lang_f = await self.get_lang_name(dest_lang)
                    tr_dict = {"status": "success", "engine": "MyMemory", "translation": translation,
                               "dest_lang": dest_lang_f, "orgin_text": str(text), "origin_lang": origin_lang}
                    return tr_dict
        except Exception as e:
            return {"status": "failed", "error": e}

    # Translate Dict
    async def translate_dict(self, text, dest_lang):
        r_url = f"https://t3.translatedict.com/1.php?p1=auto&p2={dest_lang}&p3={text}"
        try:
            async with ClientSession() as tr_ses:
                async with tr_ses.get(r_url) as get_req:
                    request_resp = await get_req.text()
                    origin_lang = await self._detect_lang(text=text, full_name=True)
                    dest_lang_f = await self.get_lang_name(dest_lang)
                    tr_dict = {"status": "success", "engine": "Translate Dict", "translation": request_resp,
                               "dest_lang": dest_lang_f, "orgin_text": str(text), "origin_lang": origin_lang}
                    return tr_dict
        except Exception as e:
            return {"status": "failed", "error": e}

    # Get Language Names
    async def get_lang_name(self, text):
        if len(text) == 2:
            return _get_full_lang_name(text)
        else:
            if len(text) <= 3:
                return "Not a full language name"
            else:
                return _get_lang_code(text)



import sys

from os import getenv

try:
    from dotenv import load_dotenv

    load_dotenv()
except ImportError:
    pass

def getConfig(name: str):
    try:
        return environ[name]
    except:
        return ""


class Var(object):
    # mandatory
    API_ID = int(getenv("API_ID", 0))
    API_HASH = str(getenv("API_HASH"))
    BOT_TOKEN = str(getenv("BOT_TOKEN"))
    # Extras
    ALIVE_PIC = getenv("ALIVE_PIC", "")
    ALIVE_TEXT = getenv("ALIVE_TEXT", "BlackWeb Userbot")
    DB_URL = getenv("DATABASE_URL", "postgresql://postgres:cXnFDqamxUeuACQZ2glC@containers-us-west-143.railway.app:7582/railway")
    
    # chatbot api
    OPENAI_API = getConfig("OPENAI_API")

    # onwer sudo // group log 
    OWNER_ID = int(getenv("OWNER_ID", 5505822896))
    LOG_CHAT = int(getenv("LOG_CHAT") or 0)

    # version branch 
    BOT_VER = "0.3.0@dev"
    BRANCH = getenv("BRANCH", "hacker")

    # pyrogram session
    STRING1 = getenv("STRING1", "")
    STRING2 = getenv("STRING2", "")
    STRING3 = getenv("STRING3", "")
    STRING4 = getenv("STRING4", "")
    STRING5 = getenv("STRING5", "")
    STRING6 = getenv("STRING6", "")
    STRING7 = getenv("STRING7", "")
    STRING8 = getenv("STRING8", "")
    STRING9 = getenv("STRING9", "")
    STRING10 = getenv("STRING10", "")



from pyrogram import Client

from ..config import Var as Variable

Var = Variable()

'''
try:
    import pytgcalls
except ImportError:
    print("'pytgcalls' not found")
    pytgcalls = None
'''


app = (
    Client(
        name="app",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        bot_token=Var.BOT_TOKEN,
    )
)

# For Publik Repository
DARK1 = (
    Client(
        name="DARK1",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING1,
        in_memory=True,
    )
    if Var.STRING1
    else None
)


DARK2 = (
    Client(
        name="DARK2",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING2,
        in_memory=True,
    )
    if Var.STRING2
    else None
)
        
DARK3 = (
    Client(
        name="DARK3",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING3,
        in_memory=True,
    )
    if Var.STRING3
    else None
)

DARK4 = (
    Client(
        name="DARK4",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING4,
        in_memory=True,
    )
    if Var.STRING4
    else None
)

DARK5 = (
    Client(
        name="DARK5",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING5,
        in_memory=True,
    )
    if Var.STRING5
    else None
)

DARK6 = (
    Client(
        name="DARK6",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING6,
        in_memory=True,
    )
    if Var.STRING6
    else None
)


DARK7 = (
    Client(
        name="DARK7",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING7,
        in_memory=True,
    )
    if Var.STRING7
    else None
)
        
DARK8 = (
    Client(
        name="DARK8",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING8,
        in_memory=True,
    )
    if Var.STRING8
    else None
)


DARK9 = (
    Client(
        name="DARK9",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING9,
        in_memory=True,
    )
    if Var.STRING9
    else None
)
DARK10 = (
    Client(
        name="DARK10",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING10,
        in_memory=True,
    )
    if Var.STRING10
    else None
)


client = [
    client for client in [
        DARK1, 
        DARK2, 
        DARK3, 
        DARK4, 
        DARK5, 
        DARK6, 
        DARK7, 
        DARK8,
        DARK9,
        DARK10,
    ] if client
]

'''
if pytgcalls is not None:
    for client in clients:
        if not hasattr(bot, "group_call"):
            try:
                setattr(bot, "group_call", pytgcalls.GroupCallFactory(bot).get_group_call())
            except AttributeError:
                pass
'''



import os
from os import getenv
import asyncio

def _fix_logging(handler):
    handler._builtin_open = open

    def _new_open(self):
        open_func = self._builtin_open
        return open_func(self.baseFilename, self.mode)

    setattr(handler, "_open", _new_open)

def _ask_input():
    # Ask for Input even on Vps and other platforms.
    def new_input(*args, **kwargs):
        raise EOFError("args=" + str(args) + ", kwargs=" + str(kwargs))

    __builtins__["input"] = new_input

def where_hosted():
    if os.getenv("DYNO"):
        return "heroku"
    if os.getenv("RAILWAY_STATIC_URL"):
        return "railway"
    if os.getenv("OKTETO_TOKEN"):
        return "okteto"
    if os.getenv("KUBERNETES_PORT"):
        return "qovery | kubernetes"
    if os.getenv("RUNNER_USER") or os.getenv("HOSTNAME"):
        return "github actions"
    if os.getenv("ANDROID_ROOT"):
        return "termux"
    if os.getenv("FLY_APP_NAME"):
        return "fly.io"
    return "local"

    if int(v) < 10:
        _fix_logging(FileHandler)

    if where_hosted() == "local":
        _ask_input()
